==> haskell-enclosed-exceptions-1.0.3-192-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 enclosed-exceptions
version:              1.0.3
visibility:           public
id:                   enclosed-exceptions-1.0.3-GLR0BMPxc8HCwIfpdO4nu5
key:                  enclosed-exceptions-1.0.3-GLR0BMPxc8HCwIfpdO4nu5
license:              MIT
maintainer:           jmacristovao@gmail.com, michael@snoyman.com
author:               Michael Snoyman, João Cristóvão
homepage:             https://github.com/jcristovao/enclosed-exceptions
synopsis:             Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>

category:             Control
abi:                  6e6d6c28f5be57ff030100ccdd6fff6f
exposed:              True
exposed-modules:      Control.Exception.Enclosed
import-dirs:          /usr/lib/ghc-9.0.2/site-local/enclosed-exceptions-1.0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-enclosed-exceptions
hs-libraries:         HSenclosed-exceptions-1.0.3-GLR0BMPxc8HCwIfpdO4nu5
depends:
    base-4.15.1.0 deepseq-1.4.5.0
    lifted-base-0.2.3.12-1Bu0mPoVYbSBed7aK7s29A
    monad-control-1.0.3.1-HkiinuOeT8TKb2uZbjvoYb transformers-0.5.6.2
    transformers-base-0.4.6-Krt9Mny97mFI6zwkIY4Uue

haddock-interfaces:
    /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enclosed-exceptions-1.0.3-193-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 enclosed-exceptions
version:              1.0.3
visibility:           public
id:                   enclosed-exceptions-1.0.3-Jdl27NXUy9a97FkDsc39TA
key:                  enclosed-exceptions-1.0.3-Jdl27NXUy9a97FkDsc39TA
license:              MIT
maintainer:           jmacristovao@gmail.com, michael@snoyman.com
author:               Michael Snoyman, João Cristóvão
homepage:             https://github.com/jcristovao/enclosed-exceptions
synopsis:             Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>

category:             Control
abi:                  88d1754867799613ab21370f2cea0a8d
exposed:              True
exposed-modules:      Control.Exception.Enclosed
import-dirs:          /usr/lib/ghc-9.0.2/site-local/enclosed-exceptions-1.0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-enclosed-exceptions
hs-libraries:         HSenclosed-exceptions-1.0.3-Jdl27NXUy9a97FkDsc39TA
depends:
    base-4.15.1.0 deepseq-1.4.5.0
    lifted-base-0.2.3.12-Bi47W7dIcnZGKlwg8stC8j
    monad-control-1.0.3.1-A10z0BeOAGys9XF8o3vyn transformers-0.5.6.2
    transformers-base-0.4.6-Iv23bfaB9S7861wmKQfWW8

haddock-interfaces:
    /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
